@@ -1,4 +1,4 @@
-def print_lol(mylist, level):
+def print_lol(mylist, level=0):
   for each_item in mylist:
     if isinstance(each_item, list):
       print_lol(each_item,level+1)
